@@ -1,6 +1,6 @@
 /*
- * Copyright 2016-2018 Brad Lanam Walnut Creek CA USA
- * Copyright 2023-2025 Brad Lanam, Pleasant Hill, CA
+ * Copyright 2016-2026 Brad Lanam Walnut Creek CA USA
+ * Copyright 2023-2026 Brad Lanam, Pleasant Hill, CA
  */
 
 #ifndef INC_DI_H
@@ -143,7 +143,7 @@ extern int di_check_option (void *di_data, int optidx);
 extern void di_format_iter_init (void *di_data);
 extern int di_format_iterate (void *di_data);
 
-extern void di_get_all_disk_info (void *di_data);
+extern int di_get_all_disk_info (void *di_data);
 extern int di_iterate_init (void *di_data, int itertype);
 extern const di_pub_disk_info_t *di_iterate (void *di_data);
 extern int di_get_scale_max (void *, int, int, int, int);
