@@ -1,6 +1,6 @@
 /*
- * Copyright 1994-2018 Brad Lanam, Walnut Creek, CA
- * Copyright 2023-2025 Brad Lanam, Pleasant Hill, CA
+ * Copyright 1994-2026 Brad Lanam, Walnut Creek, CA
+ * Copyright 2023-2026 Brad Lanam, Pleasant Hill, CA
  */
 
 #include "config.h"
@@ -371,7 +371,7 @@ chkMountOptions (const char *mntopts, const char *str)
   tstr = strdup (mntopts);
   if (tstr == (char *) NULL) {
     fprintf (stderr, "strdup failed in chkMountOptions (1).  errno %d\n", errno);
-    exit (1);
+    return (char *) NULL;
   }
   ptr = di_strtok (tstr, ",", &tokstr);
   while (ptr != (char *) NULL) {
