@@ -16,6 +16,7 @@
 
 # disable path name expansion
 set -f  # set this globally.
+origcwd=`pwd`
 
 unset CDPATH
 # this is a workaround for ksh93 on solaris
@@ -36,9 +37,6 @@ MKC_FILES=${MKC_FILES:-mkc_files}
 LOG="${MKC_FILES}/mkconfig.log"
 _MKCONFIG_TMP="${MKC_FILES}/_tmp_mkconfig"
 CACHEFILE="${MKC_FILES}/mkconfig.cache"
-OPTIONFILE="options.dat"
-_MKCONFIG_PREFIX=mkc    # need a default in case no units loaded
-optionsloaded=F
 allchglist=""
 
 INC="mkcinclude.txt"                   # temporary
@@ -97,8 +95,7 @@ _savecache () {
 }
 
 setvariable () {
-    prefix=$1
-    svname=$2
+    svname=$1
 
     if [ $varsfileopen = F ]; then
       for v in `set | grep "^mkv_" | sed -e 's/=.*$//'`; do
@@ -109,7 +106,7 @@ setvariable () {
       exec 8>>$VARSFILE
     fi
 
-    cmd="test \"X\$mkv_${prefix}_${svname}\" != X > /dev/null 2>&1"
+    cmd="test \"X\$mkv_${svname}\" != X > /dev/null 2>&1"
     eval $cmd
     rc=$?
     # if already in the list of vars, don't add it to the file again.
@@ -117,32 +114,30 @@ setvariable () {
       puts ${svname} >&8
     fi
 
-    cmd="mkv_${prefix}_${svname}=T"
+    cmd="mkv_${svname}=T"
     eval $cmd
     puts "   setvariable: $cmd" >&9
 }
 
 setdata () {
-    prefix=$1
-    sdname=$2
-    sdval=$3
+    sdname=$1
+    sdval=$2
 
     if [ "$_MKCONFIG_EXPORT" = T ]; then
       _doexport $sdname "$sdval"
     fi
 
-    cmd="mkc_${prefix}_${sdname}=\"${sdval}\""
+    cmd="mkc_${sdname}=\"${sdval}\""
     eval $cmd
     puts "   setdata: $cmd" >&9
-    setvariable $prefix $sdname
+    setvariable $sdname
 }
 
 getdata () {
     var=$1
-    prefix=$2
-    gdname=$3
+    gdname=$2
 
-    cmd="${var}=\${mkc_${prefix}_${gdname}}"
+    cmd="${var}=\${mkc_${gdname}}"
     eval $cmd
 }
 
@@ -207,13 +202,12 @@ printyesno () {
 }
 
 checkcache_val () {
-  prefix=$1
-  tname=$2
+  tname=$1
 
-  getdata tval ${prefix} ${tname}
+  getdata tval ${tname}
   rc=1
   if [ "$tval" != "" ]; then
-    setvariable $prefix $tname
+    setvariable $tname
     printyesno_actual $tname "$tval" " (cached)"
     rc=0
   fi
@@ -221,41 +215,18 @@ checkcache_val () {
 }
 
 checkcache () {
-  prefix=$1
-  tname=$2
+  tname=$1
 
-  getdata tval ${prefix} ${tname}
+  getdata tval ${tname}
   rc=1
   if [ "$tval" != "" ]; then
-    setvariable $prefix $tname
+    setvariable $tname
     printyesno $tname $tval " (cached)"
     rc=0
   fi
   return $rc
 }
 
-_loadoptions () {
-  if [ $optionsloaded = F -a -f "${OPTIONFILE}" ]; then
-    exec 6<&0 < ${OPTIONFILE}
-    while read o; do
-      case $o in
-        "")
-          continue
-          ;;
-        \#*)
-          continue
-          ;;
-      esac
-
-      topt=`puts "$o" | sed 's/=.*//'`
-      tval=`puts "$o" | sed 's/.*=//'`
-      eval "_mkc_opt_${topt}=\"${tval}\""
-    done
-    exec <&6 6<&-
-    optionsloaded=T
-  fi
-}
-
 check_command () {
     name=$1
     shift
@@ -264,7 +235,7 @@ check_command () {
     locnm=_cmd_loc_${ccmd}
 
     printlabel $name "command: ${ccmd}"
-    checkcache ${_MKCONFIG_PREFIX} $name
+    checkcache $name
     if [ $rc -eq 0 ]; then return; fi
 
     trc=0
@@ -280,9 +251,9 @@ check_command () {
     done
 
     printyesno_val $name $val
-    setdata ${_MKCONFIG_PREFIX} ${name} ${trc}
+    setdata ${name} ${trc}
     if [ $trc -eq 1 ]; then
-      setdata ${_MKCONFIG_PREFIX} ${locnm} ${val}
+      setdata ${locnm} ${val}
     fi
 }
 
@@ -295,71 +266,15 @@ check_grep () {
   locnm=_grep_${name}
 
   printlabel $name "grep: ${tag}"
-  checkcache ${_MKCONFIG_PREFIX} $name
+  checkcache $name
   if [ $rc -eq 0 ]; then return; fi
 
-  grep -l ${pat} ${fn} > /dev/null 2>&1
+  ${grepcmd} -l ${pat} ${fn} > /dev/null 2>&1
   rc=$?
   if [ $rc -eq 0 ]; then trc=1; else trc=0; fi
 
   printyesno $name $trc
-  setdata ${_MKCONFIG_PREFIX} ${name} ${trc}
-}
-
-check_ifoption () {
-    ifdispcount=$1
-    type=$2
-    name=$3
-    oopt=$4
-
-    printlabel $name "$type ($ifdispcount): ${oopt}"
-
-    _loadoptions
-    trc=0  # if option is not set, it's false
-
-    found=F
-    if [ $optionsloaded = T ]; then
-      eval tval=\$_mkc_opt_${oopt}
-      # override the option value with the environment variable
-      eval tenvval=\$${oopt}
-      if [ "$tenvval" != "" ]; then
-        tval=$tenvval
-      fi
-      if [ "$tval" != "" ]; then
-        found=T
-        trc=$tval
-        tolower trc
-        puts "  found option: $oopt $trc" >&9
-        if [ "$trc" = t ]; then trc=1; fi
-        if [ "$trc" = f ]; then trc=0; fi
-        if [ "$trc" = enable ]; then trc=1; fi
-        if [ "$trc" = disable ]; then trc=0; fi
-        if [ "$trc" = true ]; then trc=1; fi
-        if [ "$trc" = false ]; then trc=0; fi
-        if [ "$trc" = yes ]; then trc=1; fi
-        if [ "$trc" = no ]; then trc=0; fi
-      fi
-    fi
-
-    # these must be set before ifnotoption processing
-    if [ $optionsloaded = F ]; then
-      trc=0
-    elif [ "$found" = F ]; then
-      trc=0
-    fi
-
-    if [ $type = ifnotoption ]; then
-      if [ $trc -eq 0 ]; then trc=1; else trc=0; fi
-    fi
-
-    if [ $optionsloaded = F ]; then
-      printyesno_actual $name "no options file"
-    elif [ "$found" = F ]; then
-      printyesno_actual $name "option not found"
-    else
-      printyesno $name $trc
-    fi
-    return $trc
+  setdata ${name} ${trc}
 }
 
 check_if () {
@@ -413,7 +328,7 @@ check_if () {
 
       if [ $ineq -eq 1 ]; then
         ineq=2
-        getdata tvar ${_MKCONFIG_PREFIX} $token
+        getdata tvar $token
       elif [ $ineq -eq 2 ]; then
         doappend nline " ( '$tvar' = '$token' )"
         ineq=0
@@ -426,7 +341,7 @@ check_if () {
             doappend nline " $token"
             ;;
           *)
-            getdata tvar ${_MKCONFIG_PREFIX} $token
+            getdata tvar $token
             if [ "$tvar" != 0 -a "$tvar" != "" ]; then tvar=1; else tvar=0; fi
             tvar="( $tvar = 1 )"
             doappend nline " $tvar"
@@ -467,49 +382,43 @@ check_set () {
     getdata tval ${prefix} ${nm}
     if [ "$tval" != "" ]; then
       printyesno $nm "${sval}"
-      setdata ${_MKCONFIG_PREFIX} ${nm} "${sval}"
+      setdata ${nm} "${sval}"
     else
       printyesno_actual $nm "no such variable"
     fi
   elif [ "$type" = setint ]; then
     printyesno_actual $nm "${sval}"
-    setdata ${_MKCONFIG_PREFIX} ${nm} "${sval}"
+    setdata ${nm} "${sval}"
   else
     printyesno_actual $nm "${sval}"
-    setdata ${_MKCONFIG_PREFIX} ${nm} "${sval}"
+    setdata ${nm} "${sval}"
   fi
 }
 
-_read_option () {
-  onm=$1
-  def=$2
-
-  _loadoptions
-
-  oval=$def
-  if [ $optionsloaded = T ]; then
-    eval tval=\$_mkc_opt_${onm}
-    if [ "$tval" != "" ]; then
-      found=T
-      puts "  found option: $onm $tval" >&9
-      oval="$tval"
-    fi
+check_env () {
+  type=$1
+  envvar=$2
+  dflt=$3
+  quoted=0
+  if [ "x$dflt" = xquote ]; then
+    quoted=1
+    dflt=$4
   fi
-}
 
-check_option () {
-  nm=$1
-  onm=$2
-  def=$3
+  name="_${type}_${envvar}"
+  qname="_${type}quote_${envvar}"
+  printlabel $name "env: ${envvar}"
+  # do not check the cache
 
-  name=$nm
-
-  printlabel $name "option: ${onm}"
-
-  _read_option $onm "$def"
-
-  printyesno_actual $nm "$oval"
-  setdata ${_MKCONFIG_PREFIX} ${nm} "${oval}"
+  eval "${envvar}=\${${envvar}:-${dflt}}"
+  eval val="\$${envvar}"
+  trc=0
+  if [ "x$val" != x ]; then
+    trc=1
+  fi
+  printyesno_val $name "$val"
+  setdata ${name} "${val}"
+  setdata ${qname} $quoted
 }
 
 check_echo () {
@@ -584,7 +493,7 @@ _create_output () {
     if [ -f $VARSFILE ]; then
       exec 6<&0 < $VARSFILE
       while read cfgvar; do
-        getdata val ${_MKCONFIG_PREFIX} $cfgvar
+        getdata val $cfgvar
         output_item ${CONFH} ${cfgvar} "${val}" >&8
       done
       exec <&6 6<&-
@@ -640,8 +549,8 @@ main_process () {
   # a main loadunit will override this.
   # but don't open it unless it is needed.
   varsfileopen=F
-  if [ "$VARSFILE" = "" -a "${_MKCONFIG_PREFIX}" != "" ]; then
-    VARSFILE="../mkc_none_${_MKCONFIG_PREFIX}.vars"
+  if [ "$VARSFILE" = "" ]; then
+    VARSFILE="../mkc_none.vars"
   fi
 
   # ksh93 93u 'read' changed.  Need the raw read for 'include'.
@@ -699,7 +608,7 @@ main_process () {
             puts "## else: ifcurrlvl: $ifcurrlvl doif: $doif doproc:$doproc" >&9
           fi
           ;;
-        "if "*|"ifoption"*|"ifnotoption"*)
+        "if "*)
           if [ $doproc -eq 0 ]; then
             domath ifcurrlvl "$ifcurrlvl + 1"
             puts "## if: ifcurrlvl: $ifcurrlvl doif: $doif" >&9
@@ -735,6 +644,10 @@ main_process () {
 
       if [ $doproc -eq 1 ]; then
         case ${tdatline} in
+          \#*)
+            ;;
+          "")
+            ;;
           command*)
             _chkconfigfname
             set $tdatline
@@ -766,23 +679,6 @@ main_process () {
             ;;
           endinclude)
             ;;
-          ifoption*|ifnotoption*)
-            _chkconfigfname
-            set $tdatline
-            type=$1
-            opt=$2
-            nm="_${type}_${opt}"
-            puts "## if: ifcurrlvl: $ifcurrlvl" >&9
-            domath ifstmtcount "$ifstmtcount + 1"
-            check_ifoption $ifstmtcount $type ${nm} ${opt}
-            rc=$?
-            iflevels="+$ifstmtcount $iflevels"
-            _setifleveldisp
-            puts "## ifopt iflevels: $iflevels" >&9
-            doproclist="$doproc $doproclist"
-            doproc=$rc
-            puts "## doproc: $doproc doproclist: $doproclist" >&9
-            ;;
           "if "*)
             _chkconfigfname
             set $tdatline
@@ -823,33 +719,7 @@ main_process () {
               exec 8>&-
               varsfileopen=F
             fi
-            if [ "${_MKCONFIG_PREFIX}" != "" ]; then
-              VARSFILE="../mkc_${CONFHTAG}_${_MKCONFIG_PREFIX}.vars"
-            fi
-            ;;
-          option-file*)
-            set $tdatline
-            type=$1
-            file=$2
-            case ${file} in
-              /*)
-                OPTIONFILE=${file}
-                ;;
-              *)
-                OPTIONFILE="../../${file}"
-                ;;
-            esac
-            puts "option-file: ${file}" >&1
-            puts "   option file name: ${OPTIONFILE}" >&9
-            ;;
-          option*)
-            _chkconfigfname
-            set $tdatline
-            optnm=$2
-            shift; shift
-            tval=$@
-            nm="_opt_${optnm}"
-            check_option ${nm} $optnm "${tval}"
+            VARSFILE="../mkc_${CONFHTAG}.vars"
             ;;
           output*)
             newout=F
@@ -889,9 +759,7 @@ main_process () {
             CONFHTAG=$file
             CONFHTAGUC=$file
             toupper CONFHTAGUC
-            if [ "${_MKCONFIG_PREFIX}" != "" ]; then
-              VARSFILE="../mkc_${CONFHTAG}_${_MKCONFIG_PREFIX}.vars"
-            fi
+            VARSFILE="../mkc_${CONFHTAG}.vars"
             inproc=1
             ;;
           standard)
@@ -938,8 +806,7 @@ main_process () {
 }
 
 usage () {
-  puts "Usage: $0 [-C] [-c <cache-file>] [-o <options-file>]
-           [-L <log-file>] <config-file>
+  puts "Usage: $0 [-C] [-c <cache-file>] [-L <log-file>] <config-file>
   -C : clear cache-file
 defaults:
   <cache-file> : mkconfig.cache
@@ -975,11 +842,6 @@ while test $# -gt 1; do
       LOG=$1
       shift
       ;;
-    -o)
-      shift
-      OPTIONFILE=$1
-      shift
-      ;;
   esac
 done
 
@@ -1003,7 +865,6 @@ LOG="../../$LOG"
 REQLIB="../../$REQLIB"
 CACHEFILE="../../$CACHEFILE"
 VARSFILE="../../$VARSFILE"
-OPTIONFILE="../../$OPTIONFILE"
 CONFH=none
 CONFHTAG=none
 CONFHTAGUC=NONE
