@@ -64,11 +64,11 @@ preconfigfile () {
 
   # log all of the compiler and linker options
   for nm in CC CFLAGS_OPTIMIZE CFLAGS_DEBUG CFLAGS_INCLUDE CFLAGS_USER \
-      CFLAGS_APPLICATION CFLAGS_COMPILER \
+      CFLAGS_APPLICATION CFLAGS_COMPILER CFLAGS_COMPILER_APP \
       CFLAGS_SYSTEM CFLAGS_SHARED \
       CFLAGS_SHARED_USER LDFLAGS_OPTIMIZE LDFLAGS_DEBUG LDFLAGS_USER \
-      LDFLAGS_APPLICATION LDFLAGS_COMPILER LDFLAGS_SYSTEM \
-      LDFLAGS_SHARED LDFLAGS_SHARED_LIBLINK LDFLAGS_SHARED_USER \
+      LDFLAGS_APPLICATION LDFLAGS_COMPILER LDFLAGS_COMPILER_APP \
+      LDFLAGS_SYSTEM LDFLAGS_SHARED LDFLAGS_SHARED_USER \
       LDFLAGS_LIBS_USER LDFLAGS_LIBS_APPLICATION LDFLAGS_LIBS_SYSTEM; do
     cmd="puts \"$nm: \${$nm}\""
     eval $cmd >&9
